import 'package:flutter/material.dart';
import 'package:flutter/src/widgets/framework.dart';
import 'package:flutter/src/widgets/placeholder.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:storebounty_account/common/styles/colors.dart';
import 'package:storebounty_account/common/styles/textstles.dart';
import 'package:storebounty_account/profile/userprofile.dart';
import 'package:storebounty_account/support/support.dart';
import 'package:storebounty_account/widget/constants/constant.dart';
import 'package:storebounty_auth/storebounty_auth_v1.dart';
import 'package:storebounty_init/model/storedetailsmodel.dart';
import 'package:storebounty_init/storebountyinit.dart';

class StorebountyDrawer extends StatefulWidget {
  const StorebountyDrawer({super.key});

  @override
  State<StorebountyDrawer> createState() => _StorebountyDrawerState();
}

class _StorebountyDrawerState extends State<StorebountyDrawer> {
  Color? defaultColor;
  bool isAuth = false;

  @override
  void initState() {
    getColor();
    super.initState();
  }

  getColor() async {
    var colorString = await StoreBountyInit.getStoreColor() ?? "#000000";
    defaultColor = Color(int.parse("0xff" + colorString.substring(1)));
    var currencySymbol = await StoreBountyInit.getCurrencySymbol();
    // currency = currencySymbol!;

    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    var drawerItemList = [
      DropDownListModel(label: "My Profile", icon: "profile_icon.svg"),
      DropDownListModel(
          label: "Support",
          icon: "message_icon.svg",
          route: StoreBountySupport(
              defaultColor: defaultColor ?? AppColors.black)),
      DropDownListModel(label: "Address", icon: "message_icon.svg"),
      DropDownListModel(label: "Log out", icon: "message_icon.svg")
    ];

    return Column(
      children: [
        Row(
          children: [
            Expanded(
              child: Container(
                height: 149,
                color: Color(0xffFDEEEE),
                child: FutureBuilder<DashboardModel?>(
                    future: StoreBountyInit.getStore(),
                    builder:
                        (context, AsyncSnapshot<DashboardModel?> snapshot) {
                      return Row(
                        mainAxisAlignment: MainAxisAlignment.center,
                        children: [
                          // SvgPicture.asset("$kIconsPath/sample_logo.svg"),
                          Text(
                            "${snapshot.data?.data?.info?.name ?? "-"}",
                            style: Styles.h3(fontSize: 22),
                          )
                        ],
                      );
                    }),
              ),
            ),
          ],
        ),
        Expanded(
            child: Row(
          children: [
            Expanded(
              child: Container(
                color: defaultColor ?? AppColors.black,
                child: Column(
                  children: [
                    SizedBox(
                      height: 38,
                    ),
                    Container(
                      child: Row(
                        children: [
                          SizedBox(
                            width: 40,
                          ),
                          Text(
                            "MENU",
                            style: Styles.h3(
                                fontSize: 28, color: AppColors.whiteColor),
                          ),
                        ],
                      ),
                    ),
                    SizedBox(
                      height: 42,
                    ),
                    Container(
                      child: ListView.builder(
                          itemCount: drawerItemList.length,
                          padding: EdgeInsets.zero,
                          shrinkWrap: true,
                          itemBuilder: (context, index) {
                            return GestureDetector(
                              onTap: () async {
                                Navigator.pop(context);
                                var res = await checkIfUserIsAuth();
                                if(res == null){
                                  return;
                                }
                                if (drawerItemList[index].label == "Log out") {
                                  final response =
                                      await StorebountyAuth.logOut();
                                  
                                  return;
                                }
                                
                                if (drawerItemList[index].route != null) {
                                  Navigator.of(context).push(MaterialPageRoute(
                                    builder: (context) =>
                                        drawerItemList[index].route as Widget));
                                }
                              },
                              child: Container(
                                margin: EdgeInsets.only(bottom: 40),
                                child: Row(
                                  children: [
                                    SizedBox(
                                      width: 40,
                                    ),
                                    SvgPicture.asset(
                                      "$kIconsPath/${drawerItemList[index].icon}",
                                      color: AppColors.whiteColor,
                                    ),
                                    SizedBox(
                                      width: 28,
                                    ),
                                    Text(
                                      "${drawerItemList[index].label}",
                                      style: Styles.h3(
                                          color: AppColors.whiteColor,
                                          fontWeight: FontWeight.w400),
                                    ),
                                  ],
                                ),
                              ),
                            );
                          }),
                    ),
                    // Container(
                    //   child: Row(
                    //     children: [
                    //       SizedBox(
                    //         width: 40,
                    //       ),
                    //       SvgPicture.asset(
                    //         "$kIconsPath/profile_icon.svg",
                    //         color: AppColors.whiteColor,
                    //       ),
                    //       SizedBox(
                    //         width: 28,
                    //       ),
                    //       Text(
                    //         "My Profile",
                    //         style: Styles.h3(
                    //             color: AppColors.whiteColor,
                    //             fontWeight: FontWeight.w400),
                    //       ),
                    //     ],
                    //   ),
                    // ),
                    // SizedBox(
                    //   height: 64,
                    // ),
                    // InkWell(
                    //   onTap: () async {
                    //     // var token = await ref
                    //     //     .read(authChangeNotifier)
                    //     //     .checkIfUserIsAuth();
                    //     // if (token == null) {
                    //     //   Navigator.pop(context);
                    //     //   Navigator.pushNamed(
                    //     //       context, LoginScreen.pageId);
                    //     //   return;
                    //     // }
                    //     //
                    //     // var user = jsonDecode(await ref.read(authChangeNotifier).getUserLoginDetails());
                    //     // print(user['email_verified']);
                    //     // if(user['email_verified'] == false){
                    //     //   ref.read(authChangeNotifier).sendEmailOtp(context, ref);
                    //     //   Navigator.pop(context);
                    //     //   Navigator.pushNamed(
                    //     //       context, VerifyEmail.pageId);
                    //     //   return;
                    //     // }
                    //     //
                    //     // Navigator.pop(context);
                    //     // Navigator.pushNamed(
                    //     //     context, NotificationScreen.pageId);
                    //     // Navigator.of(context).push(MaterialPageRoute(builder: (context) => StoreBountySupport()));
                    //   },
                    //   child: Container(
                    //     child: Row(
                    //       children: [
                    //         SizedBox(
                    //           width: 40,
                    //         ),
                    //         SvgPicture.asset(
                    //           "$kIconsPath/message_icon.svg",
                    //           color: AppColors.whiteColor,
                    //         ),
                    //         SizedBox(
                    //           width: 28,
                    //         ),
                    //         Text(
                    //           "Support",
                    //           style: Styles.h3(
                    //               color: AppColors.whiteColor,
                    //               fontWeight: FontWeight.w400),
                    //         ),
                    //       ],
                    //     ),
                    //   ),
                    // ),
                    // SizedBox(
                    //   height: 64,
                    // ),
                    // InkWell(
                    //     onTap: () {
                    //       Navigator.pop(context);
                    //       // Navigator.pushNamed(
                    //       //     context, ViewAddresses.pageId);
                    //     },
                    //     child: MenuOptions(
                    //       label: 'Address',
                    //     )),
                    // SizedBox(
                    //   height: 64,
                    // ),
                    // InkWell(
                    //     onTap: () async {
                    //       Navigator.pop(context);
                    //       await StorebountyAuth.logOut();
                    //       setState(() {});
                    //     },
                    //     child: MenuOptions(
                    //       label: 'Log out',
                    //     ))
                  ],
                ),
              ),
            ),
          ],
        ))
      ],
    );
  }

  checkIfUserIsAuth() async {
    final response = await StorebountyAuth.checkIfUserIsLoggedIn();

    if (response == null) {
      setState(() {
        isAuth = false;
      });
      Navigator.of(context).push(MaterialPageRoute(
          builder: (context) => StorebountyAuthPage(
                onLoginSuccess: () {
                  setState(() {
                    isAuth = true;
                  });
                  Navigator.pop(context);
                },
                onLoginFailed: () {
                  setState(() {
                    isAuth = false;
                  });
                },
              )));
      return null;
    } else {
      setState(() {
        isAuth = true;
      });
      return true;
    }
  }
}

class MenuOptions extends StatelessWidget {
  final String label;
  const MenuOptions({
    super.key,
    required this.label,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Row(
        children: [
          SizedBox(
            width: 40,
          ),
          SvgPicture.asset(
            "$kIconsPath/location_icon.svg",
            color: AppColors.whiteColor,
          ),
          SizedBox(
            width: 28,
          ),
          Text(
            "$label",
            style: Styles.h3(
                color: AppColors.whiteColor, fontWeight: FontWeight.w400),
          ),
        ],
      ),
    );
  }
}
