import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:storebounty_account/widget/constants/constant.dart';
import 'package:storebounty_account/common/styles/colors.dart';
import 'package:storebounty_account/common/styles/textstles.dart';
import 'package:storebounty_cart_manager/model/cartmodel.dart';
import 'package:storebounty_cart_manager/storebounty_cart_manager.dart';

class TabAppBar extends StatelessWidget implements PreferredSizeWidget {
  final double height;
  final String title;
  final VoidCallback leftOnClick;

  TabAppBar({this.height = kToolbarHeight, required this.title, required this.leftOnClick});

  @override
  Size get preferredSize => Size.fromHeight(height);

  @override
  Widget build(BuildContext context) {
    return Container(
      color: AppColors.whiteColor,
      child: Column(
        children: [
          SizedBox(
            height: 25,
          ),
          Expanded(
            child: Container(
              // set your desired background color
              child: Row(
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  // SizedBox(width: 1,),
                  Container(
                      margin: EdgeInsets.only(left: 28),
                      child: SvgPicture.asset(
                        "$kIconsPath/arrow_back_icon.svg",
                        height: 24,
                        width: 24,
                      )),
                  SizedBox(
                    width: 52,
                  ),
                  Text(
                    '$title',
                    textAlign: TextAlign.center,
                    style: Styles.p0(fontWeight: FontWeight.w600, fontSize: 18),
                  ),
                  Spacer(),
                  InkWell(
                    onTap: leftOnClick,
                    child: Stack(
                      children: [
                        Container(
                          height: 40,
                          width: 40,
                          margin: EdgeInsets.only(right: 20),
                          child: Center(
                              child: SvgPicture.asset(
                                "assets/icons/cart_icon.svg",
                                package: 'storebounty_account',
                                color: Colors.black,
                              )),
                          decoration: BoxDecoration(
                              color: Colors.black
                                  .withOpacity(0.05),
                              shape: BoxShape.circle),
                        ),
                        FutureBuilder<List<CartModel>>(
                          future: StoreBountyCartManager.getCartItems(),
                          builder: (context, AsyncSnapshot<List<CartModel>> snapshot) {
                            if(snapshot.hasData){
                                return Visibility(
                                visible: snapshot.data!.isNotEmpty,
                                child: Positioned(
                                    right: 25,
                                    top: 10,
                                    child: Container(
                                      height: 10,
                                      width: 10,
                                      decoration: BoxDecoration(
                                          shape: BoxShape.circle,
                                          color: Colors.red
                                      ),
                                    )),
                              );
                            }else if(snapshot.hasError){
                                return Container();
                            }else{
                              return Container();
                            }
                            
                          }
                        )
                      ],
                    ),
                  )
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }
}