import 'package:flutter/material.dart';
import 'package:flutter/src/widgets/framework.dart';
import 'package:flutter/src/widgets/placeholder.dart';
import 'package:storebounty_account/common/tabbar.dart';
import 'package:storebounty_account/model/ordermodel.dart' as orderModel;
import 'package:storebounty_account/storebounty_account.dart';
import 'package:storebounty_account/common/styles/colors.dart';
import 'package:storebounty_account/common/styles/textstles.dart';
import 'package:storebounty_auth/storebounty_auth_v1.dart';
import 'package:storebounty_init/storebountyinit.dart';

class OrderHistory extends StatefulWidget {
  final Color? defaultColor;
  const OrderHistory({super.key, this.defaultColor});

  @override
  State<OrderHistory> createState() => _OrderHistoryState();
}

class _OrderHistoryState extends State<OrderHistory> {
  List<dynamic> favList = [];
  PageController pageController = PageController();
  int currentIndex = 0;
  bool isAuth = false;

  @override
  void initState() {
    checkIfUserIsAuth();
    super.initState();
  }

  checkIfUserIsAuth() async {
    final response = await StorebountyAuth.checkIfUserIsLoggedIn();

    if (response == null) {
      setState(() {
        isAuth = false;
      });
      Navigator.of(context).push(MaterialPageRoute(
          builder: (context) => StorebountyAuthPage(
                onLoginSuccess: () {
                  setState(() {
                    isAuth = true;
                  });
                  Navigator.pop(context);
                },
                onLoginFailed: () {
                  setState(() {
                    isAuth = false;
                  });
                },
              )));
    } else {
      setState(() {
        isAuth = true;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: TabAppBar(
        title: 'Order History',
        leftOnClick: () {},
      ),
      body: isAuth == false
          ? Container(
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      InkWell(
                        onTap: () {
                          Navigator.of(context).push(MaterialPageRoute(
                              builder: (context) => StorebountyAuthPage(
                                    onLoginSuccess: () {
                                      setState(() {
                                        isAuth = true;
                                      });
                                      Navigator.pop(context);
                                    },
                                    onLoginFailed: () {
                                      setState(() {
                                        isAuth = false;
                                      });
                                    },
                                  )));
                        },
                        child: Container(
                          child: Padding(
                            padding: const EdgeInsets.all(8.0),
                            child: Text(
                              "Login",
                              style: Styles.p3(color: Colors.white),
                            ),
                          ),
                          decoration: BoxDecoration(
                              color: widget.defaultColor ?? Color(0xff000000)),
                        ),
                      ),
                    ],
                  )
                ],
              ),
            )
          : Container(
              child: Column(
                children: [
                  // Container(
                  //   child: SvgPicture.asset("$kImagePath/fav_empty.svg", height: 400, width: 400,),
                  // )
                  Container(
                    margin: EdgeInsets.symmetric(horizontal: 24),
                    decoration: BoxDecoration(
                        color: Color(0xffE1E1E1),
                        borderRadius: BorderRadius.circular(4)),
                    child: Padding(
                      padding: const EdgeInsets.all(8.0),
                      child: Row(
                        children: [
                          Expanded(
                            child: InkWell(
                              onTap: () {
                                pageController.jumpToPage(0);
                                setState(() {
                                  currentIndex = 0;
                                });
                              },
                              child: Container(
                                decoration: BoxDecoration(
                                    color: currentIndex == 0
                                        ? AppColors.black
                                        : Color(0xffE1E1E1),
                                    borderRadius: BorderRadius.circular(4)),
                                child: Padding(
                                  padding: const EdgeInsets.all(8.0),
                                  child: Center(
                                      child: Text(
                                    "Ongoing ",
                                    style: Styles.p3(
                                        color: currentIndex == 0
                                            ? Color(0xffE1E1E1)
                                            : AppColors.black),
                                  )),
                                ),
                              ),
                            ),
                          ),
                          Expanded(
                            child: InkWell(
                              onTap: () {
                                pageController.jumpToPage(1);
                                setState(() {
                                  currentIndex = 1;
                                });
                              },
                              child: Container(
                                child: Padding(
                                  padding: const EdgeInsets.all(8.0),
                                  child: Center(
                                      child: Text("Completed ",
                                          style: Styles.p3(
                                              color: currentIndex == 1
                                                  ? AppColors.whiteColor
                                                  : AppColors.black))),
                                ),
                                decoration: BoxDecoration(
                                    color: currentIndex == 1
                                        ? AppColors.black
                                        : Color(0xffE1E1E1),
                                    borderRadius: BorderRadius.circular(4)),
                              ),
                            ),
                          )
                        ],
                      ),
                    ),
                  ),
                  Expanded(
                    child: PageView(
                      controller: pageController,
                      onPageChanged: (value) {
                        setState(() {
                          currentIndex = value;
                        });
                      },
                      children: [
                        OngoingScreen(
                          type: "others",
                        ),
                        OngoingScreen(
                          type: "delivered",
                        )
                      ],
                    ),
                  )
                ],
              ),
            ),
    );
  }
}

class OngoingScreen extends StatefulWidget {
  final String type;
  final Color? defaultColor;
  const OngoingScreen({super.key, required this.type, this.defaultColor});

  @override
  State<OngoingScreen> createState() => _OngoingScreenState();
}

class _OngoingScreenState extends State<OngoingScreen> {
  List<orderModel.Content> orderList = [];

  @override
  void initState() {
    getOrderHistory();
    super.initState();
  }

  Future getOrderHistory() async {
    try {
      final response = await StoreBountyAccount.getUserPurchases();

      var data = orderModel.orderModelFromMap(response.body);

      orderList.addAll(data.data!.content!);

      setState(() {});
    } catch (e) {
      print(e);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: RefreshIndicator(
        onRefresh: getOrderHistory,
        child: Container(
          child: Column(
            children: [
              SizedBox(
                height: 30,
              ),
              Expanded(
                child: widget.type == "delivered"
                    ? ListView.builder(
                        itemCount: orderList.length,
                        physics: const AlwaysScrollableScrollPhysics(),
                        itemBuilder: (context, index) {
                          final data = orderList[index];
                          return widget.type == "success"
                              ? Container(
                                  margin: EdgeInsets.symmetric(horizontal: 24),
                                  child: Column(
                                    children: [
                                      Row(
                                        children: [
                                          Expanded(
                                              child: Text(
                                            "444",
                                            style: Styles.p0(
                                                fontWeight: FontWeight.w600),
                                          )),
                                          Text("Order number : ${data.id}"),
                                        ],
                                      ),
                                      SizedBox(
                                        height: 4,
                                      ),
                                      Row(
                                        children: [
                                          Expanded(
                                              child: Text(
                                            // "${StoreBountyAccount.convertDateToTimeAndDate(data.createdAt)}",
                                            'date',
                                            style: Styles.p3(
                                                fontWeight: FontWeight.w400,
                                                fontSize: 14,
                                                color: AppColors.black
                                                    .withOpacity(0.5)),
                                          )),
                                          Text("View order details",
                                              style: Styles.p3(
                                                  fontWeight: FontWeight.w500,
                                                  fontSize: 12,
                                                  color: widget.defaultColor ??
                                                      Color(0xff000000))),
                                        ],
                                      ),
                                      SizedBox(
                                        height: 5,
                                      ),
                                      Divider(),
                                      SizedBox(
                                        height: 5,
                                      )
                                    ],
                                  ),
                                )
                              : Container();
                        })
                    : ListView.builder(
                        itemCount: orderList.length,
                        itemBuilder: (context, index) {
                          final data = orderList[index];
                          return Container(
                            margin: EdgeInsets.symmetric(horizontal: 24),
                            child: Column(
                              children: [
                                Row(
                                  children: [
                                    Expanded(
                                        child: Text(
                                      "${data.orderDesc}",
                                      style: Styles.p0(
                                          fontWeight: FontWeight.w600),
                                    )),
                                    Text("Order number : ${data.id}"),
                                  ],
                                ),
                                SizedBox(
                                  height: 4,
                                ),
                                Row(
                                  children: [
                                    Expanded(
                                        child: Text(
                                      "${StoreBountyAccount.convertDateToTimeAndDate(data.createdAt)}",
                                      style: Styles.p3(
                                          fontWeight: FontWeight.w400,
                                          fontSize: 14,
                                          color:
                                              AppColors.black.withOpacity(0.5)),
                                    )),
                                    Text("View order details",
                                        style: Styles.p3(
                                            fontWeight: FontWeight.w500,
                                            fontSize: 12,
                                            color: widget.defaultColor ??
                                                Color(0xff000000))),
                                  ],
                                ),
                                SizedBox(
                                  height: 5,
                                ),
                                Divider(),
                                SizedBox(
                                  height: 5,
                                )
                              ],
                            ),
                          );
                        }),
              )
            ],
          ),
        ),
      ),
    );
  }
}
