import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:storebounty_account/common/styles/colors.dart';
import 'package:storebounty_account/common/styles/textstles.dart';
import 'package:storebounty_account/common/tabbar.dart';
import 'package:storebounty_account/support/support.dart';
import 'package:storebounty_account/widget/constants/constant.dart';
import 'package:storebounty_auth/storebounty_auth_v1.dart';
import 'package:storebounty_init/storebountyinit.dart';

class StoreBountyUserProfile extends StatefulWidget {
  const StoreBountyUserProfile({super.key});

  @override
  State<StoreBountyUserProfile> createState() => _StoreBountyUserProfileState();
}

class _StoreBountyUserProfileState extends State<StoreBountyUserProfile> {

  Color? defaultColor;
  bool isAuth = false;

  @override
  void initState() {
    checkIfUserIsAuth();
    getColor();
    super.initState();
  }

  getColor() async {
    var colorString = await StoreBountyInit.getStoreColor() ?? "#000000";
    defaultColor = Color(int.parse("0xff" + colorString.substring(1)));
    var currencySymbol = await StoreBountyInit.getCurrencySymbol();
    setState(() {});
  }

  checkIfUserIsAuth() async {
    final response = await StorebountyAuth.checkIfUserIsLoggedIn();

    if (response == null) {
      setState(() {
        isAuth = false;
      });
      Navigator.of(context).push(MaterialPageRoute(
          builder: (context) => StorebountyAuthPage(
                onLoginSuccess: () {
                  setState(() {
                    isAuth = true;
                  });
                  Navigator.pop(context);
                },
                onLoginFailed: () {
                  setState(() {
                    isAuth = false;
                  });
                },
              )));
    } else {
      setState(() {
        isAuth = true;
      });
    }
  }

  @override
  Widget build(BuildContext context) {

    var accountData = <DropDownListModel>[
    DropDownListModel(
      label:"My Profile",
      icon:"profile.svg",
      route: Container()
    ),
    // DropDownListModel(
    //   label:"My Orders",
    //   icon:"order_icon.svg",
    //   route: Container()
    // ),
    DropDownListModel(
      label:"Support",
      icon:"chat_icon.svg",
      route: StoreBountySupport(defaultColor: defaultColor ?? AppColors.black)
    ),
    DropDownListModel(
      label:"Address",
      icon:"address_icon.svg",
      route: Container()
    ),
    DropDownListModel(
      label:"Sign out",
      icon:"signout_icon.svg",
      route: Container()
    )
  ];

    return Scaffold(
      appBar: TabAppBar(
          title: 'My Account',
          leftOnClick: () {},
        ),
        body: isAuth == false
          ? Container(
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      InkWell(
                        onTap: () {
                          Navigator.of(context).push(MaterialPageRoute(
                              builder: (context) => StorebountyAuthPage(
                                    onLoginSuccess: () {
                                      setState(() {
                                        isAuth = true;
                                      });
                                      Navigator.pop(context);
                                    },
                                    onLoginFailed: () {
                                      setState(() {
                                        isAuth = false;
                                      });
                                    },
                                  )));
                        },
                        child: Container(
                          child: Padding(
                            padding: const EdgeInsets.all(8.0),
                            child: Text(
                              "Login",
                              style: Styles.p3(color: Colors.white),
                            ),
                          ),
                          decoration: BoxDecoration(
                              color: defaultColor ?? Color(0xff000000)),
                        ),
                      ),
                    ],
                  )
                ],
              ),
            )
          : Container(
          child: ListView.builder(
            itemCount: accountData.length,
            shrinkWrap: true,
            itemBuilder: (context, index){
            return GestureDetector(
              onTap: () async {
                if(accountData[index].label == "Sign out"){
                  final response = await StorebountyAuth.logOut();
                  checkIfUserIsAuth();
                  return;
                }
                Navigator.of(context).push(MaterialPageRoute(builder: (context) => accountData[index].route as Widget));
              },
              child: Container(
                margin: EdgeInsets.symmetric(horizontal: 20),
                child: Column(
                  mainAxisSize: MainAxisSize.min,
                  children: [
                    Container(
                      margin: EdgeInsets.symmetric(vertical: 10),
                      child: Row(children: [
                        SvgPicture.asset("$kIconsPath/${accountData[index].icon}", package: 'storebounty_account',),
                        SizedBox(width: 10,),
                        Text("${accountData[index].label}", style: Styles.p0(fontWeight: FontWeight.w400),)
                      ]),
                    ),
                    Divider()
                  ],
                ),
              ),
            );
          }),
        ),
    );
  }
}


class DropDownListModel {
    String? label;
    String? icon;
    Widget? route;

    DropDownListModel({
        this.label,
        this.icon,
        this.route,
    });

    factory DropDownListModel.fromJson(Map<String, dynamic> json) => DropDownListModel(
        label: json["label"],
        icon: json["icon"],
        route: json["route"],
    );

    Map<String, dynamic> toJson() => {
        "label": label,
        "icon": icon,
        "route": route,
    };
}
