library storebounty_account;

import 'dart:convert';
import 'dart:io';

import 'package:html_unescape/html_unescape.dart';
import 'package:intl/intl.dart';
import 'package:storebounty_account/common/exception.dart';
import 'package:storebounty_account/common/extentions.dart';
import 'package:storebounty_account/model/singleproductmodel.dart' as singleModel;
import 'package:storebounty_init/storebountyinit.dart';

export 'favourites/favourites.dart';
export 'orderhistory/orderhistory.dart';


class StoreBountyAccount {

    Future getUserFavourites()async{


    }

    

    static stripHtml<String>(String value) {
      final _htmlRegex = RegExp(r'<[^>]*>');
      var unescape = HtmlUnescape();

      var text = unescape.convert(value.toString().replaceAll(_htmlRegex, ''));

      return text;
    }

  static convertDateToTimeAndDate<String>(String value) {
    return DateFormat.yMMMMd('en_US')
        .add_jm()
        .format(DateTime.parse(value.toString()));
  }

  static Future getUserPurchases() async {
      try {

        final jsonData = await StoreBountyInit.readJsonFromRoot();


        final response = await HttpClientClass
            .getRequestWithAuthWithToken("${jsonData['BASE_URL']}/marketplace/v1/mobile/${jsonData['STORE_ID']}/purchases");

        // print(response.body);
        if (response.statusCode == 200) {

          return response;
        } else if (response.statusCode == 412) {
          var error = jsonDecode(response.body);
          throw StoreBountyException(error['message']);
        } else {
          throw StoreBountyException("Unknown error");
        }
      } catch (e) {
        throw StoreBountyException("$e");
      }
    }

    static calculatePriceSingle<double>(singleModel.Data value, {currencySymbol}) {

      if (value.hasVariants == false) {
        if (value.pricing?.onSales == false) {
          return getCurrencySymbol(
              currencySymbol ?? "NGN") +
              "" +
              value.pricing!.currentPrice.toString().moneyFormat;
        } else {
          return getCurrencySymbol(
              currencySymbol ?? "NGN") +
              "" +
              value.pricing!.salesPrice.toString().moneyFormat;
        }
      } else {
        List<double> priceList = [];

        for (var i = 0; i < value.variantCombinations!.length; i++) {
          // priceList.add(value.variantCombinations![i]);
          if (value.variantCombinations![i].onSales = true) {
            priceList.add(value.variantCombinations![i].salesPrice.toDouble());
            priceList.sort();
            return getCurrencySymbol(
                currencySymbol ?? "NGN") +
                "" +
                priceList[0].toString().moneyFormat;
          } else {
            priceList.add(value.variantCombinations![i].currentPrice.toDouble());
            priceList.sort();
            return getCurrencySymbol(
                currencySymbol ?? "NGN") +
                "" +
                priceList[0].toString().moneyFormat;
          }
        }
      }
    }

  static String getCurrencySymbol(String? amount) {
      print(amount);
      var format =
      NumberFormat.simpleCurrency(locale: Platform.localeName, name: amount);
      return format.currencySymbol;
    }


    static Future getMessages() async {
      try {

        final jsonData = await StoreBountyInit.readJsonFromRoot();


        final response = await HttpClientClass
            .getRequestWithAuthWithToken("${jsonData['BASE_URL']}/accounts/api/v1/messaging/customers/messages?page=0&size=20");

        // print(response.body);
        if (response.statusCode == 200) {

          return response;
        } else if (response.statusCode == 412) {
          var error = jsonDecode(response.body);
          throw StoreBountyException(error['message']);
        } else {
          var error = jsonDecode(response.body);
          throw StoreBountyException("${error['message']}");
        }
      } catch (e) {
        throw StoreBountyException("$e");
      }
    }

    static Future sendMessage(data) async {
      try {

        final jsonData = await StoreBountyInit.readJsonFromRoot();


        final response = await HttpClientClass
            .postRequestAuthOrder("${jsonData['BASE_URL']}/accounts/api/v1/messaging/customers/messages/send", data);

        // print(response.body);
        if (response.statusCode == 200) {

          return response;
        } else if (response.statusCode == 412) {
          var error = jsonDecode(response.body);
          throw StoreBountyException(error['message']);
        } else {
          var error = jsonDecode(response.body);
          throw StoreBountyException("${error['message']}");
        }
      } catch (e) {
        throw StoreBountyException("$e");
      }
    }
    

  
}
