import 'dart:convert';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:storebounty_account/common/styles/colors.dart';
import 'package:storebounty_account/common/styles/textstles.dart';
import 'package:storebounty_account/storebounty_account.dart';
import 'package:storebounty_account/support/notification/receivedchat.dart';
import 'package:storebounty_account/support/notification/recievedimagechat.dart';
import 'package:storebounty_account/support/notification/recievedproductchat.dart';
import 'package:storebounty_account/support/notification/sendtextchat.dart';
import 'package:storebounty_account/support/pusher_service.dart';
import 'package:storebounty_account/support/pusher_singleton.dart';
import 'package:storebounty_auth/storebounty_auth_v1.dart';
import 'package:storebounty_init/storebountyinit.dart';

class ChatBox extends StatefulWidget {
  final Color defaultColor;
  const ChatBox({super.key, required this.defaultColor});

  @override
  State<ChatBox> createState() => _ChatBoxState();
}

class _ChatBoxState extends State<ChatBox> {
  PusherService pusherService = PusherService();
  List<dynamic> messages = [];
  int? conversationId;
  TextEditingController msgControllerCtx = TextEditingController();
  List<File?> imageRaw = [];
  String storeName = "";
  String isLoading = "loading";

  @override
  void initState() {
    getStoreName();
    getMessages();
    initPusher();
    super.initState();
  }

  showSavedData() async {
    var data = await StorebountyAuth.checkIfUserIsLoggedIn();

    print(data);
    setState(() {});
  }

  getStoreName() async {
    var response = await StoreBountyInit.getStore();
    storeName = response?.data?.info?.name ?? "---";
  }

  Future<void> initPusher() async {
    var user = await StorebountyAuth.getUser();

    if (user == null) {
      return;
    }

    var userChatRoom = user['chat_room_id'];

    final channel = await PusherSingleton().pusher.subscribe(
        channelName: "${userChatRoom}",
        onEvent: (event) {
          print("Event received: $event");

          if (event.eventName == "pusher:subscription_succeeded") {
            return;
          }

          var res = jsonDecode(event.data)['message'];
          print("dsadasd asdasdas asdasds ${res['id']}");
          // var channelTypeCheck = res['channelType'];
          // if(channelTypeCheck == "b2b"){

          var data = {
            "id": res['id'],
            "ownMessage": res['ownMessage'],
            "sender": {
              "last_seen": res['sender']['last_seen'],
              "avatar_url": res['sender']['avatar_url'],
              "name": res['sender']['name'],
              "email": res['sender']['email']
            },
            "channelType": res['channelType'],
            "message": res['message'],
            "senderUserId": res['senderUserId'],
            "recipientUserId": res['recipientUserId'],
            "createdAt": PusherSingleton()
                .convertStringDateToDateTime(res['createdAt'].toString())
                .toString(),
            "attachmentKey": res['attachmentKey'],
            "baseUrl": res['baseUrl'],
            "extraPayload": res['extraPayload'],
            "messageType": res['messageType'],
            "conversationId": res['conversationId'],
            "unreadCount": res['unreadCount'],
            "previewText": res['previewText'],
            "deviceId": res['deviceId']
          };

          messages.insert(0, data);

          setState(() {});
        });
  }

  Future getMessages() async {
    try {
      setState(() {
        isLoading = "loading";
      });
      messages.clear();

      final response = await StoreBountyAccount.getMessages();

      var data = jsonDecode(response.body);

      conversationId = data['data']['conversation_id'];
      messages.addAll(data['data']['messages']);

      print(response.body);

      print(data['data']);

      isLoading = "success";

      setState(() {});
    } catch (e) {
      print(e);
      setState(() {
        isLoading = "error";
      });
    }
  }

  Future sendMessage(context) async {
    try {
      var body;

      if (imageRaw.isNotEmpty) {
        body = {
          "conversation_id": "${conversationId}",
          "message_type": "IMAGE",
          "message": msgControllerCtx.text.trim(),
          "attachment_key": null,
          "base_url": null,
          "extra_payload": null
        };
      } else if (msgControllerCtx.text.trim().isNotEmpty) {
        body = {
          "conversation_id": "${conversationId}",
          "message_type": "TEXT",
          "message": msgControllerCtx.text.trim(),
          "attachment_key": null,
          "base_url": null,
          "extra_payload": null
        };
      }

      msgControllerCtx.clear();

      print(body);

      final response = await StoreBountyAccount.sendMessage(body);

      print(response.body);

      var res = jsonDecode(response.body)['data']['message'];

      var data = {
        "id": res['id'],
        "ownMessage": res['ownMessage'],
        "sender": {
          "last_seen": res['sender']['last_seen'],
          "avatar_url": res['sender']['avatar_url'],
          "name": res['sender']['name'],
          "email": res['sender']['email']
        },
        "channelType": res['channelType'],
        "message": res['message'],
        "senderUserId": res['senderUserId'],
        "recipientUserId": res['recipientUserId'],
        "createdAt": res['createdAt'],
        "attachmentKey": res['attachmentKey'],
        "baseUrl": res['baseUrl'],
        "extraPayload": res['extraPayload'],
        "messageType": res['messageType'],
        "conversationId": res['conversationId'],
        "unreadCount": res['unreadCount'],
        "previewText": res['previewText'],
        "deviceId": res['deviceId']
      };

      messages.insert(0, data);

      setState(() {});
    } catch (e) {
      print(e);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        child: Column(
          children: [
            Container(
              width: MediaQuery.of(context).size.width,
              decoration: BoxDecoration(
                  // color: colorNot.customColor.primaryColor
                  ),
              // height: 100,

              child: Container(
                margin: EdgeInsets.symmetric(horizontal: 20),
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    SizedBox(
                      height: 50,
                    ),
                    Row(
                      children: [
                        Expanded(
                            child: Row(
                          children: [
                            Text(
                              "${storeName}",
                              style: Styles.p0(
                                  color: AppColors.black,
                                  fontWeight: FontWeight.w700),
                            ),
                            SizedBox(
                              width: 10,
                            ),
                            Visibility(
                              visible: isLoading == "loading",
                              child: SizedBox(
                                  height: 15,
                                  width: 15,
                                  child: CircularProgressIndicator(
                                    strokeWidth: 2,
                                    color: widget.defaultColor,
                                  )),
                            )
                          ],
                        )),
                        IconButton(
                            onPressed: () {
                              Navigator.pop(context);
                            },
                            icon: Icon(
                              Icons.close,
                              color: AppColors.black,
                            ))
                      ],
                    ),
                  ],
                ),
              ),
            ),
            Expanded(
                child: Container(
              child: ListView.builder(
                  reverse: true,
                  itemCount: messages.length,
                  itemBuilder: (context, index) {
                    final data = messages[index];
                    return data['ownMessage'] == true
                        ? SentChat(
                            message: data,
                          )
                        : data['messageType'] == "TEXT"
                            ? ReceivedChat(
                                message: data,
                              )
                            : data['messageType'] == "PRODUCT"
                                ? ReceivedProductChat(
                                    message: data,
                                  )
                                : ReceivedImageChat(
                                    message: data,
                                  );
                  }),
            )),
            Visibility(
              visible: isLoading == "success",
              child: Container(
                // height: 100,
                child: Column(
                  children: [
                    Divider(),
                    Container(
                      margin: EdgeInsets.symmetric(horizontal: 20),
                      child: TextFormField(
                        decoration: InputDecoration(
                            hintText: 'Write a reply...',
                            border: InputBorder.none),
                        controller: msgControllerCtx,
                      ),
                    ),
                    Container(
                      margin: EdgeInsets.symmetric(horizontal: 20),
                      child: Row(
                        children: [
                          IconButton(
                              onPressed: () async {
                                // final XFile? photo = await notificationNot.picker.pickImage(source: ImageSource.gallery);

                                // if (photo != null) {
                                //   File file = File(photo.path);
                                //   notificationNot.imageRaw.add(file);
                                // } else {
                                //   // User canceled the picker
                                // }
                              },
                              icon: Icon(Icons.image)),
                          IconButton(
                              onPressed: () async {
                                // final XFile? photo = await notificationNot.picker.pickImage(source: ImageSource.camera);

                                // if (photo != null) {
                                //   File file = File(photo.path);
                                //   notificationNot.imageRaw.add(file);
                                // } else {
                                //   // User canceled the picker
                                // }
                              },
                              icon: Icon(Icons.camera_alt)),
                          Spacer(),
                          InkWell(
                              onTap: () {
                                sendMessage(context);
                              },
                              child: Text("Send"))
                        ],
                      ),
                    ),
                    SizedBox(
                      height: 20,
                    )
                  ],
                ),
              ),
            )
          ],
        ),
      ),
    );
  }
}
