import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:storebounty_account/common/styles/colors.dart';
import 'package:storebounty_account/common/styles/textstles.dart';
import 'package:storebounty_account/widget/constants/constant.dart';

class ReceivedImageChat extends StatelessWidget {
  final dynamic message;
  final Color? defaultColor;
  const ReceivedImageChat({Key? key, this.message, this.defaultColor}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
          margin: EdgeInsets.symmetric(horizontal: 14, vertical: 10),
          constraints: BoxConstraints(
              minWidth: 10, maxWidth: (MediaQuery.of(context).size.width - 100)),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.start,
            crossAxisAlignment: CrossAxisAlignment.start,
            mainAxisSize: MainAxisSize.min,
            children: [
              Container(
                child: Container(
                  height: 26,
                  width: 26,
                  decoration: BoxDecoration(
                      image: DecorationImage(image: NetworkImage(message?['sender']?['avatarUrl'] ?? "${defaultImage}")),
                      color: defaultColor ?? AppColors.black, shape: BoxShape.circle),
                ),
              ),
              SizedBox(
                width: 10,
              ),
              Container(
                width: 122,
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.end,
                  crossAxisAlignment: CrossAxisAlignment.end,
                  children: [
                    Row(
                      children: [
                        Expanded(
                          child: InkWell(
                            onTap: (){
                              _showImage(context);
                            },
                            child: Container(
                              height: 122,
                              decoration: BoxDecoration(
                                  color: Colors.black.withOpacity(0.5),
                                  borderRadius: BorderRadius.only(topRight: Radius.circular(12), topLeft: Radius.circular(12)),
                                  image: DecorationImage(image: NetworkImage("${message!['baseUrl']}${message!['attachmentKey']}"), fit: BoxFit.cover)
                              ),
                            ),
                          ),
                        ),
                      ],
                    ),
                    SizedBox(height: 10,),
                    Row(
                      // mainAxisAlignment: MainAxisAlignment.start,
                      children: [
                        SizedBox(width: 10,),
                        Text(
                          "${DateFormat.jm().format(DateTime.parse(message!['createdAt']!))}",
                          style: Styles.p3(
                              fontSize: 9, color: Colors.black.withOpacity(0.5)),
                        ),
                      ],
                    ),
                    SizedBox(height: 10,),
                  ],
                ),
                decoration: BoxDecoration(
                  color: Color(0xffF9FBFE),
                  borderRadius: BorderRadius.circular(12),
                ),
              ),
              SizedBox(
                width: 38,
              )
            ],
          ),
        );
    ;
  }

  Future<void> _showImage(context) async {
    return showDialog<void>(
      context: context,
      barrierDismissible: false, // user must tap button!
      useSafeArea: false,
      builder: (BuildContext context) {
        return AlertDialog(
          insetPadding: EdgeInsets.zero,
          backgroundColor: Colors.black,
          // contentPadding: EdgeInsets.zero,
          // title: const Text('AlertDialog Title'),
          content: ImageViewerWidget(message: message,),
          actions: <Widget>[
            // TextButton(
            //   child: const Text('Approve'),
            //   onPressed: () {
            //
            //     Navigator.of(context).pop();
            //   },
            // ),
          ],
        );
      },
    );
  }
}

class ImageViewerWidget extends StatefulWidget {
  final dynamic message;
  const ImageViewerWidget({Key? key, this.message}) : super(key: key);

  @override
  State<ImageViewerWidget> createState() => _ImageViewerWidgetState();
}

class _ImageViewerWidgetState extends State<ImageViewerWidget> {

  @override
  Widget build(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width,
      height: MediaQuery.of(context).size.height,
      child: Stack(
        children: [

          Positioned.fill(
            child: Center(
              child: Image.network("${widget.message!.baseUrl}${widget.message!.attachmentKey}"),
            ),
          ),
          Positioned(
              right: 10,
              top: 10,
              child: IconButton(
                onPressed: (){
                  Navigator.of(context).pop();
                }, icon: Icon(Icons.close, color: Colors.red,),)),

        ],
      ),
    );
  }
}
