import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:storebounty_account/common/styles/colors.dart';
import 'package:storebounty_account/common/styles/textstles.dart';
import 'package:storebounty_account/widget/constants/constant.dart';

class ReceivedProductChat extends StatefulWidget {
  final dynamic message;
  final Color? defaultColor;
  const ReceivedProductChat({Key? key, this.message, this.defaultColor}) : super(key: key);

  @override
  State<ReceivedProductChat> createState() => _ReceivedProductChatState();
}

class _ReceivedProductChatState extends State<ReceivedProductChat> {

  dynamic extraPayload = null;

  @override
  void initState(){
    processExtraPayload();
  }

  processExtraPayload(){
    var data = jsonDecode(widget.message!['extraPayload']);


    setState(() {
      extraPayload = data;
    });

  }

  @override
  Widget build(BuildContext context) {
    final msgType = widget.message?['channelType'].toString().toLowerCase();
    return Container(
          margin: EdgeInsets.symmetric(horizontal: 14, vertical: 10),
          child: Row(
            mainAxisSize: MainAxisSize.min,
            mainAxisAlignment: MainAxisAlignment.start,
            children: [
              Column(
                mainAxisAlignment: MainAxisAlignment.start,
                children: [
                  Container(
                    child: Container(
                      height: 26,
                      width: 26,
                      decoration: BoxDecoration(
                          image: DecorationImage(image: NetworkImage(widget.message?['sender']?['avatarUrl'] ?? "${defaultImage}")),
                          color: widget.defaultColor ?? AppColors.black, shape: BoxShape.circle),
                    ),
                  ),
                ],
              ),
              SizedBox(
                width: 10,
              ),
              Container(
                width: 122,
                decoration: BoxDecoration(
                    color: Color(0xffF9FBFE),
                    borderRadius: BorderRadius.circular(12)
                ),
                child: Padding(
                  padding: EdgeInsets.all(0.0),
                  child: Column(
                    mainAxisAlignment: MainAxisAlignment.end,
                    crossAxisAlignment: CrossAxisAlignment.end,
                    children: [
                      Container(
                          decoration: BoxDecoration(
                            // color: Colors.black.withOpacity(0.5)
                          ),
                          child: Column(
                            children: [
                              Row(
                                children: [
                                  Expanded(
                                    child: Container(
                                      height: 90,
                                      decoration: BoxDecoration(
                                          color: Colors.black.withOpacity(0.5),
                                          borderRadius: BorderRadius.only(topRight: Radius.circular(12), topLeft: Radius.circular(12)),
                                          image: DecorationImage(image: NetworkImage("${extraPayload['image'] == "" || extraPayload['image'] == null ? defaultImage:extraPayload['image']}"), fit: BoxFit.cover)
                                      ),
                                    ),
                                  ),
                                ],
                              ),
                              Container(
                                decoration: BoxDecoration(
                                  // color: Colors.black.withOpacity(0.2),
                                    borderRadius: BorderRadius.only(bottomRight: Radius.circular(12), bottomLeft: Radius.circular(12))
                                ),
                                child: Column(
                                  children: [
                                    Container(
                                      margin: EdgeInsets.symmetric(horizontal: 10, vertical: 5),
                                      child: Row(
                                        children: [
                                          Expanded(child: Text("${extraPayload == null ? "":extraPayload['name']}", style: Styles.p3(fontSize: 10, fontWeight: FontWeight.w500, color: Colors.black)))
                                        ],
                                      ),
                                    ),
                                    Container(
                                      margin: EdgeInsets.symmetric(horizontal: 10, vertical: 5),
                                      decoration: BoxDecoration(

                                      ),
                                      child: Column(
                                        children: [
                                          Row(
                                            children: [
                                              Text("N${extraPayload == null ? "":extraPayload['price']}", style: Styles.p3(fontSize: 8, color: Colors.black)),
                                            ],
                                          ),
                                          Divider(),
                                          Row(
                                            mainAxisAlignment: MainAxisAlignment.center,
                                            children: [
                                              Text("View Item", style: Styles.p3(fontSize: 7, color: Colors.black),)
                                            ],
                                          ),
                                          Divider(),
                                          Container(
                                            margin: EdgeInsets.only(top: 10),
                                            child: Row(
                                              mainAxisAlignment: MainAxisAlignment.end,
                                              children: [
                                                Text("${DateFormat.jm().format(DateTime.parse(widget.message!['createdAt']!))}", style: Styles.p3(fontSize: 9, color: Colors.black.withOpacity(0.5)),),
                                              ],
                                            ),
                                          )
                                        ],
                                      ),
                                    ),
                                  ],
                                ),
                              ),
                            ],
                          )),

                    ],
                  ),
                ),
              )
            ],
          ),
        );
  }
}