import 'dart:convert';

import 'package:intl/intl.dart';
import 'package:pusher_channels_flutter/pusher_channels_flutter.dart';
import 'package:storebounty_account/common/exception.dart';
import 'package:storebounty_auth/storebounty_auth_v1.dart';
import 'package:http/http.dart' as http;
import 'package:storebounty_init/storebountyinit.dart';

class PusherSingleton {
  static final PusherSingleton _singleton = PusherSingleton._internal();

  factory PusherSingleton() {
    return _singleton;
  }

  final pusher = PusherChannelsFlutter.getInstance();
  List<dynamic> messages = [];
  late PusherChannel channel;

  PusherSingleton._internal();

  Future<void> initializePusher() async {
    try {

      var user = await StorebountyAuth.getUser();

      if (user == null) {
        return;
      }

      var userChatRoom = user['chat_room_id'];

      var jsonData = await StoreBountyInit.readJsonFromRoot();

      if(jsonData == null){
        throw StoreBountyException("Pusher credentials not set");
        return;
      }

      var initPusher = await pusher.init(
        logToConsole: true,
        apiKey: "${jsonData['PUSHER_KEY']}",
        cluster: "eu",
        onAuthorizer: onAuthorizer,
        onConnectionStateChange: (value, value2) {
          print("connection status ${value2}");
        },
        onError: (value, value2, value3) {
          print("error ${value}");
        },
        onSubscriptionSucceeded: (value, value2) async {
          print("sub success ${value2}");
          // socketId = await pusher.getSocketId();
        },
        // onEvent: (event) async {
        //   print(event);

          
        //   // notifyListeners();

        // },
        onSubscriptionError: (value, value2) {
          print("sub result ${value2} ${value}");
        },
        onDecryptionFailure: (value, value2) {
          print("decrypt ${value2}");
        },
        onMemberAdded: (value, member) {},
        onMemberRemoved: (value, member) {},
      );

      // // await pusher.;
      // channel = await pusher.subscribe(
      //   channelName: "${userChatRoom}",
      // );
      // //
      await pusher.connect();
      
    } catch (e) {
      print("ERROR: $e");
    }
  }

  dynamic onAuthorizer(
      String channelName, String socketId, dynamic options) async {
    try {
      var token = await StorebountyAuth.checkIfUserIsLoggedIn();
      var clientId = 'storebounty';
      print("hhjdsf jsdhfjdhf jhfsd ${token}");
      var url =
          'https://apis-dev.ibunchng.com/accounts/api/v1/messaging/customers/authenticate?channel_name=$channelName&socket_id=$socketId';
      var result = await http.post(
        Uri.parse(url),
        headers: {
          'Content-Type': 'application/x-www-form-urlencoded',
          'Authorization': 'Bearer ${token}',
          'clientId': clientId,
          'channel': 'mobile'
        },
        body: 'socket_id=' + socketId + '&channel_name=' + channelName,
      );
      print("hhjdsf jsdhfjdhf jhfsd ${result.body}");
      var json = jsonDecode(result.body);

      print("hhjdsf jsdhfjdhf jhfsd ${json}");
      return json;
    } catch (e) {
      print(e);
    }
  }

  convertStringDateToDateTime(stringDate){

    // Use DateFormat to parse the date string
    DateFormat inputFormat = DateFormat('MMM d, yyyy h:mm:ss a');
    DateTime date = inputFormat.parse(stringDate);
    return date;
  }

  Future subscribeToPusherChannel()async{

      var user = await StorebountyAuth.getUser();

      if (user == null) {
        return;
      }

      var userChatRoom = user['chat_room_id'];

      channel = await pusher.subscribe(
          channelName: "${userChatRoom}",
      );
  }

  Future bindEvent()async{

      var user = await StorebountyAuth.getUser();

      if (user == null) {
        return;
      }

      var userChatRoom = user['chat_room_id'];

      pusher.getChannel(userChatRoom);
  }
}
