import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:storebounty_account/common/styles/colors.dart';
import 'package:storebounty_account/common/styles/textstles.dart';
import 'package:storebounty_account/support/chatbox.dart';
import 'package:storebounty_account/support/pusher_service.dart';
import 'package:storebounty_account/support/pusher_singleton.dart';
import 'package:storebounty_account/widget/custombutton.dart';
import 'package:storebounty_account/widget/custominputwithoutborder.dart';
import 'package:storebounty_auth/storebounty_auth_v1.dart';
import 'package:storebounty_init/storebountyinit.dart';


class StoreBountySupport extends StatefulWidget {
  final Color defaultColor;
  const StoreBountySupport({super.key, required this.defaultColor});

  @override
  State<StoreBountySupport> createState() => _StoreBountySupportState();
}

class _StoreBountySupportState extends State<StoreBountySupport> {
  PusherService pusherService = PusherService();
  List<dynamic> messages = [];

  @override
  void initState() {
    showSavedData();
    initPusher();
    super.initState();
  }

  showSavedData() async {
    var data = await StorebountyAuth.checkIfUserIsLoggedIn();

    print(data);
  }

  Future<void> initPusher() async {
    var user = await StorebountyAuth.getUser();

    if (user == null) {
      return;
    }

    await PusherSingleton().initializePusher();

    // var userChatRoom = user['chat_room_id'];

    // await pusherService.initPusher();

    // final channelCheck = pusherService.pusher.getChannel(userChatRoom);

    // print("channelCheck ${channelCheck?.channelName}");

    //  final channel = await pusherService.pusher.subscribe(
    //       channelName: "${userChatRoom}",
    //       onEvent: (event) {
    //         print("Event received: $event");
    //       }
    //   );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        child: Column(
          children: [
            Container(
              height: 320,
              width: MediaQuery.of(context).size.width,
              child: Stack(
                children: [
                  Container(
                    width: MediaQuery.of(context).size.width,
                    height: 230,
                    decoration: BoxDecoration(color: widget.defaultColor),
                    child: Container(
                      child: Column(
                        children: [
                          SizedBox(
                            height: 60,
                          ),
                          Row(
                            children: [
                              SizedBox(
                                width: 16,
                              ),
                              InkWell(
                                  onTap: () {
                                    Navigator.of(context).pop();
                                  },
                                  child: Icon(Icons.arrow_back,
                                      color: AppColors.whiteColor))
                            ],
                          ),
                          SizedBox(
                            height: 5,
                          ),
                          Container(
                            margin: EdgeInsets.symmetric(horizontal: 25),
                            child: Row(
                              children: [
                                FutureBuilder<dynamic>(
                                    future: StorebountyAuth.getUser(),
                                    builder: (context, AsyncSnapshot snapshot) {
                                      if (snapshot.hasData) {
                                        return Text(
                                            "Hi ${snapshot.data != null ? snapshot.data['first_name'] : ""}👋🏼",
                                            style: Styles.p0(
                                                fontSize: 20,
                                                fontWeight: FontWeight.w600,
                                                color: AppColors.whiteColor));
                                      } else if (snapshot.hasError) {
                                        return Container();
                                      } else {
                                        return Container();
                                      }
                                    })
                                // Expanded(child: Text("Hi hhhh👋🏼", style: Styles.p0(fontSize: 20, fontWeight: FontWeight.w600, color: AppColors.whiteColor),)),
                              ],
                            ),
                          ),
                          SizedBox(
                            height: 5,
                          ),
                          Container(
                            margin: EdgeInsets.symmetric(horizontal: 25),
                            child: Row(
                              children: [
                                Expanded(
                                    child: Text(
                                        "Ask us anything or share your feedback with us",
                                        style: Styles.p3(
                                            fontWeight: FontWeight.w600,
                                            color: AppColors.whiteColor))),
                              ],
                            ),
                          ),
                          // SizedBox(height: 18,),
                        ],
                      ),
                    ),
                  ),
                  Positioned(
                    bottom: 0,
                    left: 25,
                    right: 25,
                    top: 150,
                    child: Container(
                      width: MediaQuery.of(context).size.width,
                      // height: 150,
                      decoration: BoxDecoration(),
                      child: Card(
                        child: Column(
                          children: [
                            SizedBox(
                              height: 16,
                            ),
                            Container(
                              margin: EdgeInsets.symmetric(horizontal: 25),
                              child: Row(
                                children: [
                                  Expanded(
                                      child: Text(
                                          "Start a conversation with us",
                                          style: Styles.p3(
                                              fontWeight: FontWeight.w600))),
                                ],
                              ),
                            ),
                            SizedBox(
                              height: 13,
                            ),
                            Container(
                              margin: EdgeInsets.symmetric(horizontal: 25),
                              height: 40,
                              child: Row(
                                children: [
                                  Container(
                                    width: 100,
                                    child: Stack(
                                      children: [
                                        Positioned(
                                          left: 0,
                                          child: Container(
                                            height: 32,
                                            width: 32,
                                            decoration: BoxDecoration(
                                                shape: BoxShape.circle,
                                                border: Border.all(
                                                    width: 2,
                                                    color:
                                                        AppColors.whiteColor),
                                                color: widget.defaultColor),
                                          ),
                                        ),
                                        Positioned(
                                          left: 20,
                                          child: Container(
                                            height: 32,
                                            width: 32,
                                            decoration: BoxDecoration(
                                                shape: BoxShape.circle,
                                                border: Border.all(
                                                    width: 2,
                                                    color:
                                                        AppColors.whiteColor),
                                                color: widget.defaultColor),
                                          ),
                                        ),
                                        Positioned(
                                          left: 40,
                                          child: Container(
                                            height: 32,
                                            width: 32,
                                            decoration: BoxDecoration(
                                                shape: BoxShape.circle,
                                                border: Border.all(
                                                    width: 2,
                                                    color:
                                                        AppColors.whiteColor),
                                                color: widget.defaultColor),
                                          ),
                                        )
                                      ],
                                    ),
                                  ),
                                  Expanded(
                                    child: Container(
                                      child: Column(
                                        mainAxisAlignment:
                                            MainAxisAlignment.start,
                                        crossAxisAlignment:
                                            CrossAxisAlignment.start,
                                        children: [
                                          Text("Typically reply ",
                                              style: Styles.p3(
                                                  fontWeight: FontWeight.w400,
                                                  color: AppColors.black
                                                      .withOpacity(0.5))),
                                          Row(
                                            children: [
                                              Icon(Icons.access_time,
                                                  size: 15,
                                                  color: AppColors.black
                                                      .withOpacity(0.5)),
                                              SizedBox(
                                                width: 5,
                                              ),
                                              Text("under 1 minutes "),
                                            ],
                                          ),
                                        ],
                                      ),
                                    ),
                                  )
                                ],
                              ),
                            ),
                            SizedBox(
                              height: 13,
                            ),
                            Row(
                              children: [
                                SizedBox(
                                  width: 25,
                                ),
                                CustomButton(
                                    text: "text",
                                    color: widget.defaultColor,
                                    onPressed: () {
                                      // Navigator.pushNamed(context, ChatBox.pageId);
                                      Navigator.of(context)
                                          .push(MaterialPageRoute(
                                              builder: (context) => ChatBox(
                                                    defaultColor:
                                                        widget.defaultColor,
                                                  )));
                                    },
                                    customContent: Row(
                                      children: [
                                        SvgPicture.asset(
                                          "assets/icons/send_icon.svg",
                                          package: 'storebounty_account',
                                        ),
                                        SizedBox(
                                          width: 5,
                                        ),
                                        Text("Send  us a message",
                                            style: Styles.p3(
                                                fontWeight: FontWeight.w500,
                                                color: AppColors.whiteColor))
                                      ],
                                    )),
                              ],
                            ),
                            SizedBox(
                              height: 16,
                            ),
                          ],
                        ),
                      ),
                    ),
                  ),
                ],
              ),
            ),
            SizedBox(
              height: 42,
            ),
            Container(
              margin: EdgeInsets.symmetric(horizontal: 20),
              child: Row(
                children: [
                  Text(
                    "FAQs",
                    style: Styles.p0(fontSize: 20, fontWeight: FontWeight.w600),
                  ),
                ],
              ),
            ),
            SizedBox(
              height: 4,
            ),
            Container(
              margin: EdgeInsets.symmetric(horizontal: 20),
              child: CustomTextFormFieldWithoutBorder(
                hintText: 'Search for help',
                defaultColor: widget.defaultColor,
                prefixWidget: SizedBox(
                    height: 10,
                    width: 10,
                    child: SvgPicture.asset(
                      "assets/icons/explore_icon.svg",
                      fit: BoxFit.scaleDown,
                      color: AppColors.black.withOpacity(0.5),
                    )),
              ),
            ),
            Expanded(
              child: ListView.builder(
                  shrinkWrap: true,
                  itemCount: 5,
                  itemBuilder: (context, index) {
                    return Column(
                      children: [
                        Container(
                          margin: EdgeInsets.symmetric(horizontal: 20),
                          child: Row(
                            children: [
                              Expanded(
                                child: Column(
                                  mainAxisAlignment: MainAxisAlignment.start,
                                  crossAxisAlignment: CrossAxisAlignment.start,
                                  children: [
                                    Row(
                                      children: [
                                        Text("How long would delivery take ?",
                                            style: Styles.p0(
                                                fontWeight: FontWeight.w500)),
                                        Spacer(),
                                        Icon(Icons.keyboard_arrow_down_sharp)
                                      ],
                                    ),
                                    // Text(
                                    //   "dfdfdfdfd",
                                    //   style: Styles.p3(
                                    //       color:
                                    //           AppColors.black.withOpacity(0.5)),
                                    // )
                                  ],
                                ),
                              ),
                            ],
                          ),
                        ),
                        SizedBox(
                          height: 10,
                        ),
                        Container(
                            margin: EdgeInsets.symmetric(horizontal: 20),
                            child: Divider(
                              thickness: 1,
                            ))
                      ],
                    );
                  }),
            ),
          ],
        ),
      ),
    );
  }
}
