import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:flutter/src/widgets/framework.dart';
import 'package:flutter/src/widgets/placeholder.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:storebounty_account/widget/constants/constant.dart';
import 'package:storebounty_account/common/styles/colors.dart';
import 'package:storebounty_account/common/styles/textstles.dart';

class GridCard extends StatelessWidget {
  final String? amount;
  final String? title;
  final String? image;
  final Color? defaultColor;
  const GridCard({super.key, this.amount, this.title, this.image, this.defaultColor});

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Expanded(
            child: Card(
              elevation: 0,
              color: Colors.grey.withOpacity(0.2),
              shape: RoundedRectangleBorder(
                borderRadius: BorderRadius.circular(14.0),
              ),
              child: Stack(
                children: [
                  Positioned.fill(
                      child: GestureDetector(
                    onTap: () {
                      // Navigator.of(context).push(MaterialPageRoute(
                      //     builder: (context) => ProductDetails(
                      //         productId: data.id!,
                      //         goToCheckout: widget.goToCheckout)));
                    },
                    child: Container(
                      clipBehavior: Clip.hardEdge,
                      decoration: BoxDecoration(
                          borderRadius: BorderRadius.circular(14.0)),
                      child: CachedNetworkImage(
                        imageUrl: "${image}",
                        placeholder: (context, url) =>
                            const Center(child: CircularProgressIndicator()),
                        errorWidget: (context, url, error) => Center(
                            child: SvgPicture.asset(
                          "assets/icons/defaultimg.svg",
                          package: "storebounty_themes",
                          height: 100,
                          width: 100,
                        )),
                        fit: BoxFit.cover,
                      ),
                    ),
                  )),
                  Positioned(
                    top: 10,
                    right: 10,
                    child: Center(
                      child: Container(
                        height: 30,
                        width: 30,
                        decoration: const BoxDecoration(
                            shape: BoxShape.circle,
                            color: AppColors.whiteColor),
                        child: Center(
                          child: SvgPicture.asset(
                            "$kIconsPath/fav_icon.svg",
                            color: defaultColor?.withOpacity(0.5) ?? Color(0xff0000).withOpacity(0.5),
                          ),
                        ),
                      ),
                    ),
                  )
                ],
              ),
            ),
          ),
          Container(
            margin: EdgeInsets.only(left: 5),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Text(
                  "${title}",
                  style: Styles.p3(),
                ),
                Text("$amount",
                    style:
                        Styles.p3(fontSize: 14, fontWeight: FontWeight.w600)),
              ],
            ),
          ),
          SizedBox(
            height: 15,
          )
        ],
      ),
    );
  }
}
